# Security Policy

## Supported Versions

Security and bug fixes are typically provided only for the latest minor version. These fixes are released either as part of the next minor version or as patch versions when necessary.

## Reporting a Vulnerability

We welcome vulnerability reports and appreciate your efforts to improve security.

To ensure your vulnerability reports reach the maintainers promptly, please use the "Report a vulnerability" button found under the "Security" tab of this GitHub repository. This will establish a private communication channel between you and the maintainers.
